# SEU-3D

## description

3d visualization and analysis plugin for spatial transcription embryo base on napari

## updata log

[1.1.3] fix buges

[1.1.2] enrich function

[1.1.1] change color_map

[1.1.0] rebuild whole package

## acknowledge

https://github.com/GuignardLab/sc3D
https://github.com/GuignardLab/napari-sc3D-viewer

## environment
